#include "savedialog.h"
#include "ui_savedialog.h"

#include <QDir>
#include <QImageWriter>
#include <QFileDialog>
#include <QPushButton>

CSaveDialog::CSaveDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::CSaveDialog)
{
    ui->setupUi(this);
    saveAll=true;
    ui->folder->setText(QDir::homePath());
    ui->fileNameEnd->setText(QString("##."));
    ui->fileName->setText("image-");

    setAvailableFormats();
    connect(ui->BDir, SIGNAL(clicked()), this, SLOT(selectFolder()));
//    QPushButton* saveButton = ui->buttonBox->button(QDialogButtonBox::Save);
//    connect(saveButton, SIGNAL(clicked()), this, SIGNAL(accepted()));
//    QPushButton* cancelButton = ui->buttonBox->button(QDialogButtonBox::Cancel);
//    connect(cancelButton, SIGNAL(clicked()), this, SLOT(close()));

}

CSaveDialog::~CSaveDialog()
{
    delete ui;
}

bool CSaveDialog::saveAllImages()
{
    return ui->rangeAll->isChecked();
}

QString CSaveDialog::fullFilePath()
{
    return QString(ui->folder->text()+"/"+ui->fileName->text());
}

QString CSaveDialog::extension()
{
    return ui->ext->currentText();
}

void CSaveDialog::on_rangeSelected_toggled(bool checked)
{
    saveAll=!checked;
    if (checked) {
        ui->fileNameEnd->setText(".");
        ui->fileName->setText("image");
    } else {
        ui->fileNameEnd->setText(QString("##."));
        ui->fileName->setText("image-");
    }
}

void CSaveDialog::selectFolder()
{
    QString fileName = QFileDialog::getExistingDirectory(this, tr("Select folder for images"), QDir::homePath());
    if (fileName.isEmpty())
        return;
    ui->folder->setText(fileName);
}

void CSaveDialog::setAvailableFormats()
{
    QList<QByteArray> list = QImageWriter::supportedImageFormats();
    if (list.contains("png")) ui->ext->addItem("png");
    if (list.contains("bmp")) ui->ext->addItem("bmp");
    if (list.contains("jpg")) ui->ext->addItem("jpg");
    if (list.contains("tiff")) ui->ext->addItem("tiff");
}
