#include "settingsdialog.h"
#include "ui_settingsdialog.h"

#include <QDebug>
#include <QDir>
#include <QDate>
#include <QFileDialog>
#include <QMessageBox>
#include <QImageWriter>

CSettingsDialog::CSettingsDialog(bool firstRun, QWidget *parent) :
    QDialog(parent),
    ui(new Ui::CSettingsDialog)
{
    ui->setupUi(this);
    setAvailableFormats();
    m_firstRun = firstRun;
    connect(ui->bSetTempFile, SIGNAL(clicked()), this, SLOT(selectDir()));

    if (m_firstRun) {
        ui->firstRunLabel->show();
    } else {
        ui->firstRunLabel->hide();
        ui->buttonBox->addButton(QDialogButtonBox::Cancel);
        ui->line_3->hide();
    }
}

CSettingsDialog::~CSettingsDialog()
{
    delete ui;
}

QList<QVariant> CSettingsDialog::settingsList() const
{
    QList<QVariant> settings;
    settings << QVariant(ui->dirName->text()) << QVariant(ui->fileExts->currentText()) << QVariant(ui->baseFileName->text()) << QVariant(ui->startNumber->value());
    return settings;
}

void CSettingsDialog::setPath(QString path)
{
    m_dirPath = path;
    if (path.isEmpty()) {
        m_dirPath = QDir::homePath() +"/QScanner";
    }
    setDirPath();
}

void CSettingsDialog::setImageFormat(QString format)
{
    int nr = ui->fileExts->findText(format);
    if (nr != -1)
        ui->fileExts->setCurrentIndex(nr);
}

void CSettingsDialog::setStartNumber(int number)
{
    ui->startNumber->setValue(number);
}

void CSettingsDialog::setFileNameBase(QString name)
{
    if (name.isEmpty()) {
        ui->baseFileName->setText("image");
    } else {
        ui->baseFileName->setText(name);
    }
}

QString CSettingsDialog::path()
{
    return ui->dirName->text();
}

QString CSettingsDialog::imageFormat()
{
    return ui->fileExts->currentText();
}

int CSettingsDialog::startNumber()
{
    return ui->startNumber->value();
}

QString CSettingsDialog::fileNameBase()
{
    return ui->baseFileName->text();
}

void CSettingsDialog::selectDir()
{
    QString fileName = QFileDialog::getExistingDirectory(this, tr("Select folder for images"), QDir::homePath());
    if (fileName.isEmpty())
        return;
    ui->dirName->setText(fileName);
    m_dirPath = fileName;
}

void CSettingsDialog::setDirPath()
{
    QDir dir(m_dirPath);
    bool ok;
    if (!dir.exists()) {
        ok=dir.mkpath(m_dirPath);
            if (!ok) {
                QMessageBox::critical(this, tr("Error"), tr("Unable to open folder.\n Select another one."));
                qDebug() << "Dir not created!" << m_dirPath;
            }
            qDebug() << "temp dir created" << m_dirPath;
    } else {
        qDebug() << "temp dir already exists" << m_dirPath;
        ok = true;
    }
    if (ok) {
        ui->dirName->setText(m_dirPath);
    }
}

void CSettingsDialog::setAvailableFormats()
{
    QList<QByteArray> list = QImageWriter::supportedImageFormats();
    if (list.contains("png")) ui->fileExts->addItem("png");
    if (list.contains("bmp")) ui->fileExts->addItem("bmp");
    if (list.contains("jpg")) ui->fileExts->addItem("jpg");
    if (list.contains("tiff")) ui->fileExts->addItem("tiff");
}

