#ifndef IMAGE_H
#define IMAGE_H

#include <QObject>
#include <QIcon>
#include <QMutex>

class CImage : public QObject
{
    Q_OBJECT
public:
    explicit CImage(QObject *parent = 0);
    ~CImage();
    void setSettings(QList<QVariant> sets);
    //Conected with libksane
    bool addImage(QImage image);
    //conected with libksane, currently unused
    bool addImage(QByteArray &image, int width, int height, int bytespl, int format);
    //add existing image
    bool addImage(const QString filePath);
    //set   image if it was changed by user
    void setCurrentImage(const QString filePath);
    //actions
    QPixmap &currentImage();
    QPixmap &rotateLeft();
    QPixmap &rotateRight();
    QPixmap &flipHorizontally();
    QPixmap &flipVertiaclly();
    QPixmap &scale(QSize size);
    //return thumbnail ready to use as a icon in list
    QIcon thumbnail();
    //return full file Path
    QString filePath();
    //return image size and dimenssion
    QString imageInfo();
    //save current image
    void saveImage();
    //save image current image as, quality do nothing
    void saveImageAs(QString oldFilePath, QString newFilePath, QString extension, int quality = -1);
    //used when there is no image in lists
    void setVoidImage();

signals:
    //signal emited after adding new image to the program
    void imageReady(QPixmap&, QIcon, QString info);
    //singal emited after switching to a new image
    void imageOpened(QPixmap&, QString info);

public slots:
    //delete permanently file from disc
    void deleteFile (QString fileName);


private:
    //according to given settings create new image, check if file already exists
    QString createNewFullFileName();
    //set image size and dimenssion
    void estimateImageSize();
    QMutex m_mutex;
    QString m_dirPath;
    QString m_extension;
    QString m_namePattern;
    int m_imageNumber;
    QPixmap m_pixmap;
    QString m_filePath;
    QString m_imageSize;
    QString m_imageDim;
    bool m_imageChanged;


};

#endif // IMAGE_H
