#ifndef IMAGEVIEWER_H
#define IMAGEVIEWER_H

#include "imagewidget.h"
#include "image.h"

#include <QMainWindow>
#include <QListWidgetItem>

namespace Ui {
class CImageViewer;
}

class CImageViewer : public QMainWindow
{
    Q_OBJECT
    
public:
    explicit CImageViewer(CImage *image, QWidget *parent = 0);
    ~CImageViewer();
    //return opened images from imageList
    QStringList openedImages();

protected:
    void closeEvent(QCloseEvent *event);
    
private slots:
    //used when new image is added
    void newImageReady(QPixmap &image, QIcon icon, QString info);
    //used when image is changed by mouse click on list
    void newImageReady(QPixmap &image, QString info);
    void on_actionRotate_left_triggered();
    void on_actionRotate_right_triggered();
    void on_actionSave_triggered();
    void on_actionUndo_triggered();
    void on_actionFlip_horizontally_triggered();
    void on_actionFlip_vertical_triggered();
    void on_actionPrint_triggered();
    void on_actionZoom_to_fit_triggered();
    void on_actionZoom_to_100_triggered();
    void on_actionShow_images_thumbnail_triggered(bool checked);
    void changeImageOnListClicked(QListWidgetItem *itemOld, QListWidgetItem* itemNew);
    void on_actionSave_as_pdf_triggered();
    void on_actionScale_image_triggered();
    void scaleMainImage (QSize newSize);
    void on_actionZoom_in_triggered();
    void on_actionZoom_out_triggered();
    void deleteFile(QString filePath);
    void listIsEmpty();

private:
    void scaleAndFitImage (QImage& img, const QRect rect);
    void enableActions(bool enable);
    void updateLabelInfo(QString fileInfo);
    void updateZoomFactor();
    bool fileExist(QString fileName);
    void overwriteOrRenameImage(QString oldFilePath, QString newFilePath, QString extension);
    Ui::CImageViewer *ui;
    CImage *m_image;
};

#endif // IMAGEVIEWER_H
