#include "listwidget.h"
#include <QEvent>
#include <QMenu>
#include <QDebug>
#include <QProcess>
#include <QPainter>
#include <QApplication>
#include <QToolTip>
#include <QSettings>

CListWidget::CListWidget(QWidget *parent) :
    QListWidget(parent)
{

    m_menu =contextMenu();
    connect(this, SIGNAL(customContextMenuRequested(const QPoint &)), this,  SLOT(showContextMenuForWidget(const QPoint &)));
    connect(this, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(itemClicked(QListWidgetItem*)));
    m_currentItem = 0;
    m_hiddenImages = 0;
    m_saveOnExit = true;
}

CListWidget::~CListWidget()
{
    qDebug() << "~~~destr ListWidget";
}

QString CListWidget::currentItemFileName()
{
    return currentItem()->data(Qt::UserRole).toString();
}

void CListWidget::setCurrentItemFileName(QString fileName)
{
    currentItem()->setData(Qt::UserRole, fileName);
}

void CListWidget::rotateThumbnailLeft()
{
    QPixmap pix = currentItem()->icon().pixmap(200, 200);
    QTransform transform;
    transform.rotate(-90);
    pix = pix.transformed(transform);
    currentItem()->setIcon(QIcon(pix));
}

void CListWidget::rotateThumbnailRight()
{
    QPixmap pix = currentItem()->icon().pixmap(200, 200);
    QTransform transform;
    transform.rotate(90);
    pix = pix.transformed(transform);
    currentItem()->setIcon(QIcon(pix));
}

void CListWidget::flipThumbnailHorizontaly()
{
    QPixmap pix = currentItem()->icon().pixmap(200, 200);
    QTransform transform;
    transform.scale(-1,1);
    pix = pix.transformed(transform);
    currentItem()->setIcon(QIcon(pix));
}

void CListWidget::flipThumbnailVerticaly()
{
    QPixmap pix = currentItem()->icon().pixmap(200, 200);
    QTransform transform;
    transform.scale(1,-1);
    pix = pix.transformed(transform);
    currentItem()->setIcon(QIcon(pix));
}

QStringList CListWidget::fileList()
{
    QStringList list;
    if (m_saveOnExit) {
        for (int i=0; i < count(); i++) {

            list.append(item(i)->data(Qt::UserRole).toString());

        }
    }
    qDebug() << "item list: " << list.count();
    return list;
}

void CListWidget::deleteItemFromDisc()
{
    emit deleteFile(currentItemFileName());
    checkIfEmpty();
}

void CListWidget::removeItemFromList()
{

    QListWidgetItem *item = takeItem(currentRow());
    delete item;
    checkIfEmpty();
}

void CListWidget::saveListOnExit(bool save)
{
    m_saveOnExit = save;
}

void CListWidget::hideItem()
{
    currentItem()->setHidden(true);
    m_hiddenImages++;
    if (checkIfEmpty()) {
        return;
    }

    //select another image
    if (currentRow() == 0) {
        setCurrentRow(1);
    } else {
        setCurrentRow(currentRow()-1);
    }
    //emit signal to chage image
    itemClicked(currentItem());
}

void CListWidget::showHiddenItem()
{
    for (int i = 0; i < count(); i++) {
        item(i)->setHidden(false);
    }
    m_hiddenImages = 0;
}

void CListWidget::clearList()
{
    clear();
    emit listIsEmpty();
}

void CListWidget::openWith()
{
    QProcess::startDetached("gimp \"" + currentItemFileName() + "\"");
}

void CListWidget::renameFile()
{

}

void CListWidget::showContextMenuForWidget(const QPoint &pos)
{
    if (itemAt(pos)) {
        actionRemoveItem->setEnabled(true);
        actionHideItem->setEnabled(true);
        actionDeleteFromDisc->setEnabled(true);
        actionOpenWith->setEnabled(true);
        actionRenameFile->setEnabled(true);
    } else {
        actionRemoveItem->setDisabled(true);
        actionHideItem->setDisabled(true);
        actionDeleteFromDisc->setDisabled(true);
        actionOpenWith->setDisabled(true);
        actionRenameFile->setDisabled(true);
    }
    m_menu->exec(mapToGlobal(pos));
}

void CListWidget::itemClicked(QListWidgetItem *newItem)
{
    emit customItemClicked(m_currentItem, newItem);
    m_currentItem = newItem;
}

void CListWidget::paintEvent(QPaintEvent *e)
{
    QListWidget::paintEvent(e);
    if (m_hiddenImages > 0) {
        QPainter painter;
        painter.begin(viewport() );
        //rect to paint
        QFontMetrics fm(QToolTip::font());
        int fontH = fm.height()+2;
        QRect rect;
        rect.setX(0);
        rect.setY(viewport()->rect().height() - fontH);
        rect.setWidth(viewport()->rect().width());
        rect.setHeight(fontH);
        //draw tooltip rect
        const QStyle *st = QApplication::style();
        QStyleOption opt;
        opt.rect = rect;
        st->drawPrimitive(QStyle::PE_PanelTipLabel, &opt, &painter);

        //draw tooltip text
        QString text;
        if (m_hiddenImages == 1) {
           text = tr("hidden item");
        } else {
            text = tr("hidden items");
        }
        text = QString("%1 " + text).arg(m_hiddenImages);
        st->drawItemText(&painter, rect, Qt::AlignCenter, palette(), true, text, QPalette::ToolTipText );
        painter.end();
    }
}

bool CListWidget::checkIfEmpty()
{
    if (count() - m_hiddenImages == 0) {
        emit listIsEmpty();
        return true;
    }
    return false;
}

QMenu *CListWidget::contextMenu()
{
    //TODO rename file
    actionRemoveItem = new QAction(tr("Remove image from list"),this);
    actionRemoveItem->setIcon(QIcon::fromTheme("list-remove"));
    actionRemoveItem->setToolTip(tr("Remove image from list,\nImage will not be deleted from disk."));
    actionDeleteFromDisc = new QAction(tr("Delete image from disc"), this);
    actionDeleteFromDisc->setIcon(QIcon::fromTheme("edit-delete"));
    actionSaveListOnExit = new QAction(tr("Save image history on exit"),this);
    actionSaveListOnExit->setIcon(QIcon::fromTheme("view-history"));
    actionSaveListOnExit->setCheckable(true);
    actionSaveListOnExit->setChecked(true);
    actionHideItem = new QAction(tr("Hide this image"),this);
    actionHideItem->setIcon(QIcon::fromTheme("flag-black"));
    actionShowHiddenItems = new QAction(tr("Show hidden items"),this);
    actionShowHiddenItems->setIcon(QIcon::fromTheme("layer-visible-on"));
    actionClearList = new QAction(tr("Clear list"),this);
    actionClearList->setIcon(QIcon::fromTheme("edit-clear-list"));
    actionClearList->setToolTip(tr("Remove all images from list,\nImages will not be deleted from disk."));
    actionOpenWith = new QAction(tr("Open with gimp"), this);
    actionOpenWith->setIcon(QIcon::fromTheme("system-run"));
    actionRenameFile = new QAction(tr("Rename file"), this);
    actionRenameFile->setIcon(QIcon::fromTheme("edit-rename"));
    QMenu *menu = new QMenu(this);
    menu->addAction(actionDeleteFromDisc);
    menu->addAction(actionRemoveItem);   
    menu->addAction(actionHideItem);
    menu->addAction(actionOpenWith);
   // menu->addAction(actionRenameFile);
    menu->addSeparator();
    menu->addAction(actionShowHiddenItems);
    menu->addAction(actionSaveListOnExit);
    menu->addAction(actionClearList);
    connect(actionRemoveItem,SIGNAL(triggered()), this, SLOT(removeItemFromList()));
    connect(actionDeleteFromDisc,SIGNAL(triggered()), this, SLOT(deleteItemFromDisc()));
    connect(actionHideItem,SIGNAL(triggered()), this, SLOT(hideItem()));
    connect(actionShowHiddenItems,SIGNAL(triggered()), this, SLOT(showHiddenItem()));
    connect(actionSaveListOnExit,SIGNAL(triggered(bool)), this, SLOT(saveListOnExit(bool)));
    connect(actionClearList,SIGNAL(triggered()), this, SLOT(clearList()));
    connect(actionOpenWith,SIGNAL(triggered()), this, SLOT(openWith()));
    connect(actionRenameFile, SIGNAL(triggered()), this, SLOT(renameFile()));

    return menu;
}
