#ifndef LISTWIDGET_H
#define LISTWIDGET_H

#include <QListWidget>


class CListWidget : public QListWidget
{
    Q_OBJECT
public:
    explicit CListWidget(QWidget *parent = 0);
    ~CListWidget();
    //return full file path
    QString currentItemFileName (void);
    //set file path, currently unused
    void setCurrentItemFileName (QString fileName);
    void rotateThumbnailLeft();
    void rotateThumbnailRight();
    void flipThumbnailHorizontaly();
    void flipThumbnailVerticaly();
    //return list of filePaths, if don't save option is turned on return empty list
    QStringList fileList();
    
signals:
    void customItemClicked(QListWidgetItem *oldItem, QListWidgetItem *newItem);
    void deleteFile(QString filePath);
    //emited when list is empty after eg. deleting items
    void listIsEmpty();
    
public slots:
    void deleteItemFromDisc();
    void removeItemFromList();
    void saveListOnExit(bool save);
    void hideItem();
    void showHiddenItem();
    void clearList();
    void openWith();
    void renameFile();

protected slots:
    void showContextMenuForWidget(const QPoint &pos);
    void itemClicked(QListWidgetItem *newItem);

protected:
    void paintEvent(QPaintEvent *e);

private:
    //check if list is empty and emit signal to disable actions
    bool checkIfEmpty();
    QMenu* contextMenu();
    QMenu* m_menu;
    QAction *actionRemoveItem;
    QAction *actionDeleteFromDisc;
    QAction *actionSaveListOnExit;
    QAction *actionHideItem;
    QAction *actionShowHiddenItems;
    QAction *actionClearList;
    QAction *actionOpenWith;
    QAction *actionRenameFile;
    QListWidgetItem *m_currentItem;
    bool m_saveOnExit;
    int m_hiddenImages;
    
};

#endif // LISTWIDGET_H
